pub struct QueryEventsRequest {
pub run_ids: Vec<String>,
pub workspace_ids: Vec<String>,
pub kinds: Vec<String>,
pub policy_effects: Vec<i32>,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub page_size: u32,
pub page_token: String,
pub source: i32,
pub step_ids: Vec<String>,
pub ascending: bool,
pub severities: Vec<i32>,
}Fields
run_ids: Vec<String>workspace_ids: Vec<String>kinds: Vec<String>policy_effects: Vec<i32>start_time: Option<Timestamp>end_time: Option<Timestamp>page_size: u32page_token: Stringsource: i32step_ids: Vec<String>ascending: boolseverities: Vec<i32>Implementations
Sourceimpl QueryEventsRequest
impl QueryEventsRequest
Sourcepub fn policy_effects(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<PolicyDecisionEffect>>
pub fn policy_effects( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<PolicyDecisionEffect>>
Returns an iterator which yields the valid enum values contained in policy_effects.
Sourcepub fn push_policy_effects(&mut self, value: PolicyDecisionEffect)
pub fn push_policy_effects(&mut self, value: PolicyDecisionEffect)
Appends the provided enum value to policy_effects.
Sourcepub fn source(&self) -> QueryEventSource
pub fn source(&self) -> QueryEventSource
Returns the enum value of source, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source(&mut self, value: QueryEventSource)
pub fn set_source(&mut self, value: QueryEventSource)
Sets source to the provided enum value.
Sourcepub fn severities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<EventSeverity>>
pub fn severities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<EventSeverity>>
Returns an iterator which yields the valid enum values contained in severities.
Sourcepub fn push_severities(&mut self, value: EventSeverity)
pub fn push_severities(&mut self, value: EventSeverity)
Appends the provided enum value to severities.