pub struct RunTraceContext {
pub trace_id: String,
pub span_id: String,
pub parent_span_id: String,
pub run: Option<RunScope>,
pub step: Option<StepScope>,
pub tool_call: Option<ToolCallScope>,
pub policy_decision: Option<PolicyDecisionScope>,
pub budget: Option<BudgetScope>,
pub seed: Option<i64>,
pub baggage: Vec<BaggageItem>,
}Expand description
Canonical trace context shared across Tap v2 events and OpenTelemetry spans.
Fields
trace_id: Stringspan_id: Stringparent_span_id: Stringrun: Option<RunScope>step: Option<StepScope>tool_call: Option<ToolCallScope>policy_decision: Option<PolicyDecisionScope>budget: Option<BudgetScope>seed: Option<i64>baggage: Vec<BaggageItem>Trait Implementations
Sourceimpl Clone for RunTraceContext
impl Clone for RunTraceContext
Sourcefn clone(&self) -> RunTraceContext
fn clone(&self) -> RunTraceContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunTraceContext
impl Debug for RunTraceContext
Sourceimpl Default for RunTraceContext
impl Default for RunTraceContext
Sourceimpl Message for RunTraceContext
impl Message for RunTraceContext
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RunTraceContext
impl PartialEq for RunTraceContext
impl StructuralPartialEq for RunTraceContext